@@ -3,6 +3,7 @@ import datacollector_ICE
 import datacollector_Boliga
 import datacollector_Business_insider
 import datacollector_Entsoe
+import datacollector_energidataservice
 
 
 class ECB(datacollector_ECB.ECB):
@@ -20,4 +21,6 @@ class Boliga(datacollector_Boliga.Boliga):
 class Business_insider(datacollector_Business_insider.Business_insider):
     pass
 
+class Energidataservice(datacollector_energidataservice.Energidataservice):
+    pass
 
